@@ -14,13 +14,19 @@ if (exists $ENV{COUNT}) {
 my $cwd = Cwd::cwd();
 system { $^X } $^X, 'Makefile.PL' and die "Failed to $^X Makefile.PL for $ENV{FIREFOX_BINARY}";
 system { 'cover' } 'cover', '-delete' and die "Failed to 'cover' for $ENV{FIREFOX_BINARY}";
-my $path = File::Spec->catdir(File::HomeDir::my_home(), 'den');
-my $handle = DirHandle->new($path) or die "Failed to find firefox den at $path";
 system { 'make' } 'make' and die "Failed to 'make'";
 system { $^X } $^X, '-MDevel::Cover', '-Iblib/lib', '-Iblib/arch', 't/01-marionette.t' and die "Failed to 'make'";
+my $path = File::Spec->catdir(File::HomeDir::my_home(), 'den');
+my $handle = DirHandle->new($path) or die "Failed to find firefox den at $path";
+my @entries;
 while(my $entry = $handle->read()) {
 	next if ($entry eq File::Spec->updir());
 	next if ($entry eq File::Spec->curdir());
+	next if ($entry =~ /[.]tar[.]bz2$/smx);
+	push @entries, $entry;
+}
+#foreach my $entry (reverse sort { $a cmp $b } @entries) {
+foreach my $entry (sort { $a cmp $b } @entries) {
 	$ENV{FIREFOX_BINARY} = File::Spec->catfile($path, $entry, 'firefox');
 	if (-e $ENV{FIREFOX_BINARY}) {
 		system { $^X } $^X, '-MDevel::Cover', '-Iblib/lib', '-Iblib/arch', 't/01-marionette.t' and die "Failed to 'make'";
